==> picimagesearch-3.10.2.tar.gz: picimagesearch-3.10.2/README.md <==
<div align="center">

# PicImageSearch

Read this in other languages: [English](README.md), [中文](README.cn.md), [Русский](README.ru.md)

✨ Reverse Image Search Aggregator ✨

<a href="https://raw.githubusercontent.com/kitUIN/PicImageSearch/master/LICENSE">
    <img src="https://img.shields.io/github/license/kitUIN/PicImageSearch" alt="license">
</a>
<a href="https://pypi.python.org/pypi/PicImageSearch">
    <img src="https://img.shields.io/pypi/v/PicImageSearch" alt="pypi">
</a>
<img src="https://img.shields.io/badge/python-3.9+-blue" alt="python">
<a href="https://github.com/kitUIN/PicImageSearch/releases">
    <img src="https://img.shields.io/github/v/release/kitUIN/PicImageSearch" alt="release">
</a>
<a href="https://github.com/kitUIN/PicImageSearch/issues">
    <img src="https://img.shields.io/github/issues/kitUIN/PicImageSearch" alt="issues">
</a>

<a href="https://pic-image-search.kituin.fun/">📖 Documentation</a>
·
<a href="https://github.com/kitUIN/PicImageSearch/issues/new">🐛 Submit Issue</a>

</div>

## Support

| Engine   | Website                            |
|----------|------------------------------------|
| ASCII2D  | <https://ascii2d.net/>             |
| Baidu    | <https://graph.baidu.com/>         |
| E-Hentai | <https://e-hentai.org/>            |
| ExHentai | <https://exhentai.org/>            |
| Google   | <https://www.google.com/imghp>     |
| IQDB     | <https://iqdb.org/>                |
| SauceNAO | <https://saucenao.com/>            |
| TraceMoe | <https://trace.moe/>               |
| Yandex   | <https://yandex.com/images/search> |

## Usage

For details, see the [documentation](https://pic-image-search.kituin.fun/) or the [demo codes](demo/en/).  
For synchronous usage, import with `from PicImageSearch.sync import ...` .  
For asynchronous usage, import with `from PicImageSearch import Network,...` .  
**Asynchronous usage is recommended.**

### Installation

- Requires Python 3.9 or later.
- Install: `pip install PicImageSearch`
- Or use Tsinghua mirror: `pip install PicImageSearch -i https://pypi.tuna.tsinghua.edu.cn/simple`

## Star History

[![Star History](https://starchart.cc/kitUIN/PicImageSearch.svg)](https://starchart.cc/kitUIN/PicImageSearch)

==> picimagesearch-3.11.0.post1.tar.gz: picimagesearch-3.11.0.post1/README.md <==
<div align="center">

# PicImageSearch

Read in other languages: [English](README.md), [中文](README.cn.md), [Русский](README.ru.md), [日本語](README.ja.md)

✨ Aggregated Image Search Engine for Reverse Image Search ✨

<a href="https://raw.githubusercontent.com/kitUIN/PicImageSearch/master/LICENSE">
    <img src="https://img.shields.io/github/license/kitUIN/PicImageSearch" alt="license">
</a>
<a href="https://pypi.python.org/pypi/PicImageSearch">
    <img src="https://img.shields.io/pypi/v/PicImageSearch" alt="pypi">
</a>
<img src="https://img.shields.io/badge/python-3.9+-blue" alt="python">
<a href="https://github.com/kitUIN/PicImageSearch/releases">
    <img src="https://img.shields.io/github/v/release/kitUIN/PicImageSearch" alt="release">
</a>
<a href="https://github.com/kitUIN/PicImageSearch/issues">
    <img src="https://img.shields.io/github/issues/kitUIN/PicImageSearch" alt="issues">
</a>

<a href="https://pic-image-search.kituin.fun/">📖 Documentation</a>
·
<a href="https://github.com/kitUIN/PicImageSearch/issues/new">🐛 Submit an Issue</a>

</div>

## Supported Search Engines

| Engine   | Website                            |
|----------|------------------------------------|
| ASCII2D  | <https://ascii2d.net/>             |
| Baidu    | <https://graph.baidu.com/>         |
| E-Hentai | <https://e-hentai.org/>            |
| ExHentai | <https://exhentai.org/>            |
| Google   | <https://www.google.com/imghp>     |
| IQDB     | <https://iqdb.org/>                |
| SauceNAO | <https://saucenao.com/>            |
| TraceMoe | <https://trace.moe/>               |
| Yandex   | <https://yandex.com/images/search> |

## Usage

For detailed information, please refer to the [documentation](https://pic-image-search.kituin.fun/) or [example code](demo/en/).  
For `synchronous` usage, import using `from PicImageSearch.sync import ...` .  
For `asynchronous` usage, import using `from PicImageSearch import Network,...` .  
**Asynchronous usage is recommended.**

### Installation

- Requires Python 3.9 and above.
- Installation command: `pip install PicImageSearch`
- Or use the Tsinghua mirror: `pip install PicImageSearch -i https://pypi.tuna.tsinghua.edu.cn/simple`

## Star History

[![Star History](https://starchart.cc/kitUIN/PicImageSearch.svg)](https://starchart.cc/kitUIN/PicImageSearch)
